{% extends "cms/home.html" %} {% load i18n %} {% block content %} {% if 'news.add_newsitem' in perms or user.is_superuser %} {% trans "Post News Item" %} {% endif %} {% for news_item in newsitem_list %}

## {{news_item.title}}

{{news_item.publicationDate}}

{{news_item.content|safe}}
{% endfor %} {% if is_paginated %}
{% if page_obj.has_previous %} {% trans "previous" %} {% endif %} {% blocktrans with thisPage=page_obj.number numPages=page_obj.paginator.num_pages %} Page {{ thisPage }} of {{ numPages }}. {% endblocktrans %} {% if page_obj.has_next %} {% trans "next" %} {% endif %}
{% endif %} {% endblock %}